pub struct TestBuilder { /* private fields */ }Expand description
Builds and runs test suite(s).
Implementations
Sourceimpl TestBuilder
impl TestBuilder
Sourcepub fn new(proxy: RunBuilderProxy) -> Self
pub fn new(proxy: RunBuilderProxy) -> Self
Create new instance
Sourcepub fn filter_debug_data(self) -> Self
pub fn filter_debug_data(self) -> Self
Filter out debug data. On coverage builders, tests executed under test_manager produce coverage profile. This option is useful for ignoring these and ensuring the caller observes the same events on all builders.
pub fn take_proxy(self) -> RunBuilderProxy
pub fn set_scheduling_options( &self, accumulate_debug_data: bool, ) -> Result<(), Error>
Sourcepub async fn add_suite(
&self,
test_url: &str,
run_options: RunOptions,
) -> Result<SuiteRunInstance, Error>
pub async fn add_suite( &self, test_url: &str, run_options: RunOptions, ) -> Result<SuiteRunInstance, Error>
Add suite to run.
Sourcepub async fn add_suite_in_realm(
&self,
realm: ClientEnd<RealmMarker>,
offers: &[Offer],
test_collection: &str,
test_url: &str,
run_options: RunOptions,
) -> Result<SuiteRunInstance, Error>
pub async fn add_suite_in_realm( &self, realm: ClientEnd<RealmMarker>, offers: &[Offer], test_collection: &str, test_url: &str, run_options: RunOptions, ) -> Result<SuiteRunInstance, Error>
Add suite to run in a realm.
Sourcepub async fn run(self) -> Result<Vec<TestRunEvent>, Error>
pub async fn run(self) -> Result<Vec<TestRunEvent>, Error>
Runs all tests to completion and collects events alongside uncompressed debug_data. We will remove this function and merge it with run_with_option function once we remove open to get uncompressed debug_data.
Sourcepub async fn run_with_option(
self,
get_compressed_debug_data: bool,
) -> Result<Vec<TestRunEvent>, Error>
pub async fn run_with_option( self, get_compressed_debug_data: bool, ) -> Result<Vec<TestRunEvent>, Error>
Runs all tests to completion and collects events alongside compressed debug_data. We will remove this function and merge it with run once we remove open to get uncompressed debug_data.